@@ -15,6 +15,7 @@ from itertools import product
 import numpy as np
 import pandas as pd
 
+import ORBIT
 from ORBIT.phases import DesignPhase, InstallPhase
 from ORBIT.core.library import (
     initialize_library,
@@ -26,7 +27,6 @@ from ORBIT.phases.design import (
     MonopileDesign,
     ArraySystemDesign,
     ExportSystemDesign,
-    ProjectDevelopment,
     MooringSystemDesign,
     ScourProtectionDesign,
     SemiSubmersibleDesign,
@@ -58,7 +58,6 @@ class ProjectManager:
     date_format_long = "%m/%d/%Y %H:%M"
 
     _design_phases = [
-        ProjectDevelopment,
         MonopileDesign,
         ArraySystemDesign,
         CustomArraySystemDesign,
@@ -105,19 +104,22 @@ class ProjectManager:
                 *config.get("install_phases", []),
             ],
         )
+        self._phases = {}
         self.config = self.resolve_project_capacity(config)
         self.weather = self.transform_weather_input(weather)
 
-        self.phase_starts = {}
-        self.phase_times = {}
-        self.phase_costs = {}
-        self._output_logs = []
-        self._phases = {}
-
         self.design_results = {}
         self.detailed_outputs = {}
 
-    def run_project(self, **kwargs):
+        self.system_costs = {}
+        self.installation_costs = {}
+
+        # TODO: Revise:
+        self.phase_starts = {}
+        self.phase_times = {}
+        self._output_logs = []
+
+    def run(self, **kwargs):
         """
         Main project run method.
 
@@ -199,7 +201,7 @@ class ProjectManager:
             config = cls.remove_keys(config, d.output_config)
 
         config["project_parameters"] = {
-            "turbine_capex": "$/kW (optional, default: 0.0)",
+            "turbine_capex": "$/kW (optional, default: 1300)",
             "ncf": "float (optional, default: 0.4)",
             "offtake_price": "$/MWh (optional, default: 80)",
             "project_lifetime": "yrs (optional, default: 25)",
@@ -210,10 +212,15 @@ class ProjectManager:
             "contingency": "$/kW (optional, default: 316)",
             "commissioning": "$/kW (optional, default: 44)",
             "decommissioning": "$/kW (optional, default: 58)",
+            "site_auction_price": "$ (optional, default: 100e6)",
+            "site_assessment_cost": "$ (optional, default: 50e6)",
+            "construction_plan_cost": "$ (optional, default: 1e6)",
+            "installation_plan_cost": "$ (optional, default: 0.25e6)",
         }
 
         config["design_phases"] = [*design_phases.keys()]
         config["install_phases"] = [*install_phases.keys()]
+        config["orbit_version"] = str(ORBIT.__version__)
 
         return config
 
@@ -434,8 +441,6 @@ class ProjectManager:
         -------
         time : int | float
             Total phase time.
-        cost : int | float
-            Total phase cost.
         logs : list
             List of phase logs.
         """
@@ -460,10 +465,7 @@ class ProjectManager:
 
             except Exception as e:
                 print(f"\n\t - {name}: {e}")
-                self.phase_costs[name] = e.__class__.__name__
-                self.phase_times[name] = e.__class__.__name__
-
-                return None, None, None
+                return None, None
 
         else:
             phase = _class(
@@ -474,17 +476,21 @@ class ProjectManager:
         self._phases[name] = phase
 
         time = phase.total_phase_time
-        cost = phase.total_phase_cost
         logs = deepcopy(phase.env.logs)
 
         self.phase_starts[name] = start
-        self.phase_costs[name] = cost
         self.phase_times[name] = time
         self.detailed_outputs = self.merge_dicts(
             self.detailed_outputs, phase.detailed_output
         )
 
-        return cost, time, logs
+        if phase.system_capex:
+            self.system_costs[name] = phase.system_capex
+
+        if phase.installation_capex:
+            self.installation_costs[name] = phase.installation_capex
+
+        return time, logs
 
     def get_phase_class(self, phase):
         """
@@ -539,8 +545,6 @@ class ProjectManager:
 
             except Exception as e:
                 print(f"\n\t - {name}: {e}")
-                self.phase_costs[name] = e.__class__.__name__
-                self.phase_times[name] = e.__class__.__name__
                 return
 
         else:
@@ -549,8 +553,6 @@ class ProjectManager:
 
         self._phases[name] = phase
 
-        self.phase_costs[name] = phase.total_phase_cost
-        self.phase_times[name] = phase.total_phase_time
         self.design_results = self.merge_dicts(
             self.design_results, phase.design_result, overwrite=False
         )
@@ -575,7 +577,7 @@ class ProjectManager:
         start = 0
 
         for name in phase_list:
-            _, time, logs = self.run_install_phase(name, start, **kwargs)
+            time, logs = self.run_install_phase(name, start, **kwargs)
 
             if logs is None:
                 continue
@@ -607,7 +609,7 @@ class ProjectManager:
         # Run defined
         for name, start in defined.items():
 
-            _, _, logs = self.run_install_phase(name, start, **kwargs)
+            _, logs = self.run_install_phase(name, start, **kwargs)
 
             if logs is None:
                 continue
@@ -653,9 +655,7 @@ class ProjectManager:
 
                 try:
                     start = self.get_dependency_start_time(target, perc)
-                    cost, time, logs = self.run_install_phase(
-                        name, start, **kwargs
-                    )
+                    _, logs = self.run_install_phase(name, start, **kwargs)
 
                     progress = True
 
@@ -827,7 +827,7 @@ class ProjectManager:
         return rating
 
     @property
-    def project_logs(self):
+    def logs(self):
         """Returns list of all logs in the project."""
 
         if not self._output_logs:
@@ -839,7 +839,7 @@ class ProjectManager:
     def project_time(self):
         """Returns total project time as the time of the last log."""
 
-        return self.project_actions[-1]["time"]
+        return self.actions[-1]["time"]
 
     @property
     def month_bins(self):
@@ -946,7 +946,7 @@ class ProjectManager:
             for i in range(1, max(cash_flow.keys()) + 1)
         ]
 
-        return self.overnight_capex - sum(_npv)
+        return (self.total_capex - self.installation_capex) - sum(_npv)
 
     @property
     def progress_logs(self):
@@ -958,7 +958,7 @@ class ProjectManager:
         """Returns filtered list of logs."""
 
         filtered = []
-        for l in self.project_logs:
+        for l in self.logs:
             try:
                 filtered.append(tuple(l[k] for k in keys))
 
@@ -987,10 +987,10 @@ class ProjectManager:
         return summary
 
     @property
-    def project_actions(self):
+    def actions(self):
         """Returns list of all actions in the project."""
 
-        actions = [l for l in self.project_logs if l["level"] == "ACTION"]
+        actions = [l for l in self.logs if l["level"] == "ACTION"]
         return sorted(actions, key=lambda l: l["time"])
 
     @staticmethod
@@ -1064,34 +1064,6 @@ class ProjectManager:
 
         return abs((a - b).days)
 
-    @property
-    def phase_costs_per_kw(self):
-        """
-        Returns phase costs in CAPEX/kW.
-        """
-
-        _dict = {}
-        for k, capex in self.phase_costs.items():
-
-            try:
-                _dict[k] = capex / (self.capacity * 1000)
-
-            except TypeError:
-                pass
-
-        return _dict
-
-    @property
-    def overnight_capex(self):
-        """Returns the overnight capital cost of the project."""
-
-        design_phases = [p.__name__ for p in self._design_phases]
-        design_cost = sum(
-            [v for k, v in self.phase_costs.items() if k in design_phases]
-        )
-
-        return design_cost + self.turbine_capex
-
     @property
     def overnight_capex_per_kw(self):
         """
@@ -1107,25 +1079,32 @@ class ProjectManager:
         return capex
 
     @property
-    def installation_capex(self):
-        """
-        Returns installation related CAPEX.
-        """
+    def system_capex(self):
+        """Returns total system procurement CapEx."""
 
-        res = sum(
-            [
-                v
-                for k, v in self.phase_costs.items()
-                if k in self.config["install_phases"] and isinstance(v, Number)
-            ]
-        )
-        return res
+        return np.nansum([c for _, c in self.system_costs.items()])
+
+    @property
+    def system_capex_per_kw(self):
+        """Returns system CapEx/kW."""
+
+        try:
+            capex = self.system_capex / (self.capacity * 1000)
+
+        except TypeError:
+            capex = None
+
+        return capex
+
+    @property
+    def installation_capex(self):
+        """Returns total installation related CapEx."""
+
+        return np.nansum([c for _, c in self.installation_costs.items()])
 
     @property
     def installation_capex_per_kw(self):
-        """
-        Returns installation related CAPEX/kW.
-        """
+        """Returns installation CapEx/kW."""
 
         try:
             capex = self.installation_capex / (self.capacity * 1000)
@@ -1137,17 +1116,13 @@ class ProjectManager:
 
     @property
     def bos_capex(self):
-        """
-        Returns BOS CAPEX not including commissioning and decommissioning.
-        """
+        """Returns total balance of system CapEx."""
 
-        return sum([v for _, v in self.phase_costs.items()])
+        return self.system_capex + self.installation_capex
 
     @property
     def bos_capex_per_kw(self):
-        """
-        Returns BOS CAPEX/kW not including commissioning and decommissioning.
-        """
+        """Returns balance of system CapEx/kW."""
 
         try:
             capex = self.bos_capex / (self.capacity * 1000)
@@ -1163,52 +1138,33 @@ class ProjectManager:
         Returns the total turbine CAPEX.
         """
 
-        _capex = self.project_params.get("turbine_capex", 0.0)
+        _capex = self.project_params.get("turbine_capex", 1300)
         try:
             num_turbines = self.config["plant"]["num_turbines"]
             rating = self.config["turbine"]["turbine_rating"]
 
         except KeyError:
-            print(
-                f"Turbine CAPEX not included in commissioning. Required "
+            raise KeyError(
+                f"Total turbine CAPEX can't be calculated. Required "
                 f"parameters 'plant.num_turbines' or 'turbine.turbine_rating' "
                 f"not found."
             )
-            return 0.0
 
         capex = _capex * num_turbines * rating * 1000
         return capex
 
     @property
     def turbine_capex_per_kw(self):
-        """
-        Returns the turbine CAPEX/kW.
-        """
+        """Returns the turbine CapEx/kW."""
 
         _capex = self.project_params.get("turbine_capex", None)
         return _capex
 
     @property
-    def total_capex(self):
-        """
-        Returns total project CAPEX including commissioning and decommissioning.
-        """
+    def overnight_capex(self):
+        """Returns the overnight capital cost of the project."""
 
-        return self.bos_capex + self.turbine_capex + self.soft_capex
-
-    @property
-    def total_capex_per_kw(self):
-        """
-        Returns total BOS CAPEX/kW including commissioning and decommissioning.
-        """
-
-        try:
-            capex = self.total_capex / (self.capacity * 1000)
-
-        except TypeError:
-            capex = None
-
-        return capex
+        return self.system_capex + self.turbine_capex
 
     @property
     def soft_capex(self):
@@ -1239,6 +1195,61 @@ class ProjectManager:
             [insurance, financing, contingency, commissioning, decommissioning]
         )
 
+    @property
+    def project_capex(self):
+        """
+        Returns project related CapEx line items. To override the defaults,
+        the keys below should be passed to the 'project_parameters' subdict.
+        """
+
+        site_auction = self.project_params.get("site_auction_price", 100e6)
+        site_assessment = self.project_params.get("site_assessment_cost", 50e6)
+        construction_plan = self.project_params.get(
+            "construction_plan_cost", 1e6
+        )
+        installation_plan = self.project_params.get(
+            "installation_plan_cost", 0.25e6
+        )
+
+        return sum(
+            [
+                site_auction,
+                site_assessment,
+                construction_plan,
+                installation_plan,
+            ]
+        )
+
+    @property
+    def project_capex_per_kw(self):
+        """Returns project related CapEx per kW."""
+
+        try:
+            capex = self.project_capex / (self.capacity * 1000)
+
+        except TypeError:
+            capex = None
+
+        return capex
+
+    @property
+    def total_capex(self):
+        """Returns total project CapEx including soft costs."""
+
+        return self.bos_capex + self.turbine_capex + self.soft_capex
+
+    @property
+    def total_capex_per_kw(self):
+        """Returns total CapEx/kW."""
+
+        try:
+            capex = self.total_capex / (self.capacity * 1000)
+
+        except TypeError:
+            capex = None
+
+        return capex
+
     def export_configuration(self, file_name):
         """
         Exports the configuration settings for the project to
